# Contributing to the Coscine Python SDK
## General
The Coscine Python SDK is open source software and not developed by
the Coscine team. Instead it is developed by the userbase of Coscine,
which is researchers, data stewards and project managers.  
If you belong to that userbase and would like to improve this package,
you are more than welcome to contribute.  

## Contribution Workflow
The general flow of contributing to this repository is:
1. Create a fork of the repository and make your changes in your fork.
In case you are not an RWTH member you may not have full access to
the [RWTH Gitlab instance] and may not be able to fork projects.
If you would like to participate anyway, you need to be added to the project.
Please contact the [Coscine Community Team] and state your intention of
contributing to the project. They will be able to grant you developer rights,
which enable you to create merge requests inside of community repositories.
2. When you’re ready and satisfied with the changes in your fork,
   create a new merge request.
3. Ensure you provide complete and accurate information in the merge
   request’s description.
4. Once you’re ready, mark your MR as ready for review.
5. The Maintainers of this package will take a look at your contribution
   and incorporate the changes into the repository, provided no fatal flaws
   have been detected and your proposed change is actually useful.

For small suggestions / changes you can also open an issue with
a feature request.

[RWTH Gitlab instance]: https://git.rwth-aachen.de
[Coscine Community Team]: mailto:coscine-technical-adaptation@itc.rwth-aachen.de

## Code convention & Style guidelines
Consider some general guidelines to help making (your) code readable and
in line with the rest of the code in this package.

- limit the column size to 80 columns for each line
	- Tabs vs. spaces - this package uses tabs
	- Set the tabsize in your editor to 4 to be in line with the 80 column rule
- Use [numpy DOCstrings](https://numpydoc.readthedocs.io/en/latest/format.html)
  for modules, classes, methods and functions
- Write type hints
- Write self descriptive code, use sensible variable/function names
- Roughly stick to PEP8
- Try to comply with the minimum python version currently supported
  by the pacckage. This version will probably align with
  https://devguide.python.org/versions/. The CI Pipeline contains a job
  to determine the minimum python version supported.

Roughly stick to the following template for sourcecode files:
```python
###############################################################################
# Coscine Python SDK
# Copyright (c) 2018-2022 RWTH Aachen University
# Licensed under the terms of the MIT License
###############################################################################
# Coscine, short for Collaborative Scientific Integration Environment is
# a platform for research data management (RDM).
# For more information on Coscine visit https://www.coscine.de/.
#
# Please note that this python module is open source software primarily
# developed and maintained by the scientific community. It is not
# an official service that RWTH Aachen provides support for.
###############################################################################

###############################################################################
# File description
###############################################################################

"""
TODO
"""

###############################################################################
# Dependencies
###############################################################################

from __future__ import annotations

###############################################################################
# Module globals / Constants
###############################################################################

###############################################################################
# Classes / Functions / Scripts
###############################################################################

###############################################################################
```

## CI Pipelines
This repository is configured to work with a variety of static analysis tools
and automatic documentation generators. For an overview over the different
CI/CD Pipelines, have a look at [.gitlab-ci.yml](.gitlab-ci.yml).  
Install the tools mentioned in the jobs on your local system to test your
fork locally. Documentation is provided in the ci configuration file.
